@@ -10,8 +10,6 @@
 #' @param samples A list of the K samples to be studied, all following admixture distributions.
 #' @param sim_U (default to NULL) Random draws of the inner convergence part of the contrast as defined in the IBM approach (see 'Details' below).
 #' @param n_sim_tab Number of simulated gaussian processes when tabulating the inner convergence distribution in the IBM approach.
-#' @param min_size (default to NULL) Useful to provide the minimal size among all samples (needed to take into account the correction
-#'                 factor for the variance-covariance assessment). Automatically calculated if NULL.
 #' @param comp.dist A list with 2*K elements corresponding to the component distributions (specified with R native names for these distributions)
 #'                  involved in the K admixture models. Elements, grouped by 2, refer to the unknown and known components of each admixture model,
 #'                  If there are unknown elements, they must be specified as 'NULL' objects. For instance, 'comp.dist' could be specified
@@ -61,7 +59,7 @@
 #'                    f2 = NULL, g2 = list(mean = 4, sd = 1.1),
 #'                    f3 = NULL, g3 = list(mean = -3, sd = 0.8))
 #' ## Perform the 3-samples test:
-#' IBM_k_samples_test(samples = list(sim1,sim2,sim3), sim_U= NULL, n_sim_tab = 20, min_size = NULL,
+#' IBM_k_samples_test(samples = list(sim1,sim2,sim3), sim_U= NULL, n_sim_tab = 20,
 #'                    comp.dist = list.comp, comp.param = list.param, conf.level = 0.95,
 #'                    tune.penalty = FALSE, parallel = FALSE, n_cpu = 2)
 #'
@@ -84,7 +82,7 @@
 #' list.param <- list(f1 = NULL, g1 = list(mean = 2, sd = 0.7),
 #'                    f2 = NULL, g2 = list(mean = 4, sd = 1.1),
 #'                    f3 = NULL, g3 = list(mean = 3, sd = 0.8))
-#' IBM_k_samples_test(samples = list(sim1,sim2,sim3), sim_U= NULL, n_sim_tab = 20, min_size = NULL,
+#' IBM_k_samples_test(samples = list(sim1,sim2,sim3), sim_U= NULL, n_sim_tab = 20,
 #'                    comp.dist = list.comp, comp.param = list.param, conf.level = 0.95,
 #'                    tune.penalty = FALSE, parallel = FALSE, n_cpu = 2)
 #' }
@@ -92,8 +90,8 @@
 #' @author Xavier Milhaud <xavier.milhaud.research@gmail.com>
 #' @export
 
-IBM_k_samples_test <- function(samples = NULL, sim_U = NULL, n_sim_tab = 100, min_size = NULL, comp.dist = NULL,
-                               comp.param = NULL, conf.level = 0.95, tune.penalty = TRUE, parallel = FALSE, n_cpu = 2)
+IBM_k_samples_test <- function(samples = NULL, sim_U = NULL, n_sim_tab = 100, comp.dist = NULL, comp.param = NULL,
+                               conf.level = 0.95, tune.penalty = TRUE, parallel = FALSE, n_cpu = 2)
 {
   ## Control whether parallel computations were asked for or not:
   if (parallel) {
@@ -113,8 +111,7 @@ IBM_k_samples_test <- function(samples = NULL, sim_U = NULL, n_sim_tab = 100, mi
   }
 
   ## Get the minimal size among all sample sizes, useful for contrast tabulation (adjustment of covariance terms):
-  if (is.null(min_size)) { minimal_size <- min(sapply(X = samples, FUN = length))
-  } else { minimal_size <- min_size }
+  minimal_size <- min(sapply(X = samples, FUN = length))
 
   ## Look for all possible couples on which the discrepancy will be computed :
   model.list <- lapply(X = seq.int(from = 1, to = length(comp.dist), by = 2), FUN = seq.int, length.out = 2)
